@@ -16,7 +16,7 @@ Usage::
     session_client: AppConfigClient = session.client("appconfig")
     ```
 """
-from mypy_boto3_appconfig.client import AppConfigClient
+from .client import AppConfigClient
 
 Client = AppConfigClient
 
